from pathlib import Path
import shutil as shu
import dateparser as dtp


class Document:
    '''A class for module documents like
    handbooks, assignment briefs, etc.'''
    def __init__(self, name, doc_type):
        self.name = name
        self.doc_type = doc_type


    def find_document(self):
        ''' Check if there is an existing document that can be copied into place'''

    
    


    




# a = r'C:\Users\kevin.omalley\Desktop\Hero influence scale abstract.docx'
# b = r'C:\Users\kevin.omalley\Documents\GitHub\grading_colation\data\test'
# test = Document('Assignment 1 brief', a, )
# print(test.location)
# test.copyDocument(b)
