from shutil import move
from sulis_check import sulis_check
from move_submissions import move_submissions
from create_workspace import set_up




sulis_check('C:\Users\kevin.omalley\Documents\GitHub\grading_colation\data\student submissions')

move_submissions()

