'''
Created by Kev 'Sp1d3r-Z3r0' O'Malley (kevin.omalley[@]ul.ie, Github = 'https://github.com/spider-z3r0'), 19/07/2021, as part of the ULpsych grader bot package.

The aim of this module is to set up a workspace 'parent' directory which can be used to organise all the sub-directories for a particular assignment. I'm just going to play around
with this and see what happens. 
'''
from Module import module_setup

a = module_setup()